@@ -6,9 +6,8 @@ from typing import (
     Union,
 )
 from webcompy.reactive._base import ReactiveBase
-from webcompy.brython import DOMEvent
 from webcompy.elements.types._abstract import ElementAbstract
-
+from webcompy.elements._dom_objs import DOMEvent
 
 ElementChildren: TypeAlias = Union[ElementAbstract, ReactiveBase[Any], str, None]
 AttrValue: TypeAlias = Union[ReactiveBase[Any], str, int, bool]
